@@ -12,7 +12,8 @@ import time
 import xml.dom.minidom
 
 from dataclasses import dataclass
-from typing import Any, Dict, IO, Iterable, Optional, TYPE_CHECKING
+from typing import Any, IO, TYPE_CHECKING
+from collections.abc import Iterable
 
 from coverage import __version__, files
 from coverage.misc import isolate_module, human_sorted, human_sorted_items
@@ -42,7 +43,7 @@ def rate(hit: int, num: int) -> str:
 @dataclass
 class PackageData:
     """Data we keep about each "package" (in Java terms)."""
-    elements: Dict[str, xml.dom.minidom.Element]
+    elements: dict[str, xml.dom.minidom.Element]
     hits: int
     lines: int
     br_hits: int
@@ -72,10 +73,10 @@ class XmlReporter:
                     else:
                         src = files.canonical_filename(src)
                     self.source_paths.add(src)
-        self.packages: Dict[str, PackageData] = {}
+        self.packages: dict[str, PackageData] = {}
         self.xml_out: xml.dom.minidom.Document
 
-    def report(self, morfs: Optional[Iterable[TMorf]], outfile: Optional[IO[str]] = None) -> float:
+    def report(self, morfs: Iterable[TMorf] | None, outfile: IO[str] | None = None) -> float:
         """Generate a Cobertura-compatible XML report for `morfs`.
 
         `morfs` is a list of modules or file names.
@@ -94,10 +95,11 @@ class XmlReporter:
 
         # Write header stuff.
         xcoverage = self.xml_out.documentElement
+        assert xcoverage is not None
         xcoverage.setAttribute("version", __version__)
         xcoverage.setAttribute("timestamp", str(int(time.time()*1000)))
         xcoverage.appendChild(self.xml_out.createComment(
-            f" Generated by coverage.py: {__url__} "
+            f" Generated by coverage.py: {__url__} ",
         ))
         xcoverage.appendChild(self.xml_out.createComment(f" Based on {DTD_URL} "))
 
@@ -222,7 +224,7 @@ class XmlReporter:
                     xline.setAttribute("branch", "true")
                     xline.setAttribute(
                         "condition-coverage",
-                        "%d%% (%d/%d)" % (100*taken//total, taken, total)
+                        "%d%% (%d/%d)" % (100*taken//total, taken, total),
                     )
                 if line in missing_branch_arcs:
                     annlines = ["exit" if b < 0 else str(b) for b in missing_branch_arcs[line]]
